@@ -212,7 +212,7 @@ class HMMMethod(base.SingleConditionMethod):
             return None
 
         #Validate transposon types
-        if not transit_tools.validate_filetypes(ctrldata, transposons):
+        if not transit_tools.validate_transposons_used(ctrldata, transposons):
             return None
 
 
@@ -279,7 +279,7 @@ class HMMMethod(base.SingleConditionMethod):
         
         #Get data
         self.transit_message("Getting Data")
-        (data, position) = tnseq_tools.get_data(self.ctrldata)
+        (data, position) = transit_tools.get_validated_data(self.ctrldata, wxobj=self.wxobj)
         (K,N) = data.shape
 
         # Normalize data
