@@ -233,16 +233,17 @@ class Tn5GapsMethod(base.SingleConditionMethod):
         start_time = time.time()
         
         self.transit_message("Getting data (May take a while)")
-        genes_obj = tnseq_tools.Genes(self.ctrldata, self.annotation_path, ignoreCodon=self.ignoreCodon, nterm=self.NTerminus, cterm=self.CTerminus)
         
         # Combine all wigs
-        (data,position) = tnseq_tools.get_data_zero_fill(self.ctrldata)
+        (data,position) = transit_tools.get_validated_data(self.ctrldata, wxobj=self.wxobj)
         combined = tnseq_tools.combine_replicates(data, method=self.replicates)
         combined[combined < self.minread] = 0
         counts = combined
         counts[counts > 0] = 1
         num_sites = counts.size
         
+        genes_obj = tnseq_tools.Genes(self.ctrldata, self.annotation_path, ignoreCodon=self.ignoreCodon, nterm=self.NTerminus, cterm=self.CTerminus, data=data, position=position)
+        
         pins = numpy.mean(counts)
         pnon = 1.0 - pins
 
