@@ -307,7 +307,7 @@ class Genes:
 
 #
     
-    def __init__(self, wigList, annotation, norm="nonorm", reps="All", minread=1, ignoreCodon = True, nterm=0.0, cterm=0.0, include_nc = False, data=[], position=[]):
+    def __init__(self, wigList, annotation, norm="nonorm", reps="All", minread=1, ignoreCodon = True, nterm=0.0, cterm=0.0, include_nc = False, data=[], position=[],genome="", transposon="himar1"):
         """Initializes the gene list based on the list of wig files and a prot_table.
 
         This class helps define a list of Gene objects with attributes that 
@@ -349,7 +349,12 @@ class Genes:
         
         orf2info = get_gene_info(self.annotation)
         if not numpy.any(data):
-            (data, position) = get_data(self.wigList)
+            if transposon.lower() == "himar1" and not genome:
+                (data, position) = get_data(self.wigList)
+            elif genome:
+                (data, position) = get_data_w_genome(self.wigList, genome)
+            else:
+                (data, position) = get_data_zero_fill(self.wigList)
             ii_min = data < self.minread
             data[ii_min] = 0
         hash = get_pos_hash(self.annotation)
@@ -708,10 +713,39 @@ def get_file_types(wig_list):
                 tmp = line.split()
                 pos = int(tmp[0])
                 rd = float(tmp[1])
-                if pos != prev_pos + 1: types[i] = 'himar1'
+                if pos != prev_pos + 1:
+                    types[i] = 'himar1'
+                    break
                 prev_pos = pos
     return types
 
+def check_wig_includes_zeros(wig_list):
+    """Returns boolean list showing whether the given files include empty sites
+    (zero) or not.
+
+    Arguments:
+        wig_list (list): List of paths to wig files.
+
+    Returns:
+        list: List of boolean values.
+    """
+    if not wig_list:
+        return []
+    includes = [False for i in range(len(wig_list))]
+    for i, wig_filename in enumerate(wig_list):
+        with open(wig_filename) as wig_file:
+            for line in wig_file:
+                if line[0] not in "0123456789": continue
+                tmp = line.split()
+                pos = int(tmp[0])
+                rd = float(tmp[1])
+                if rd == 0:
+                    includes[i] = True
+                    break
+    return includes
+
+
+
 #
 
 def get_unknown_file_types(wig_list, transposons):
@@ -745,14 +779,25 @@ def get_data(wig_list):
     .. seealso:: :class:`get_file_types` :class:`combine_replicates` :class:`get_data_zero_fill` :class:`pytransit.norm_tools.normalize_data`
     """
     K = len(wig_list)
-    T = 0
 
+    # If empty just quickly return empty lists
     if not wig_list:
         return (numpy.zeros((1,0)), numpy.zeros(0), [])
 
-    for line in open(wig_list[0]):
-        if line[0] not in "0123456789": continue
-        T+=1
+    # Check size of all wig file matches
+    size_list = []
+    for j,path in enumerate(wig_list):
+        T = 0
+        for line in open(path):
+            if line[0] not in "0123456789": continue
+            T+=1
+        size_list.append(T)
+
+    # If it doesn't match, report and error and quit
+    if sum(size_list) != (T * len(size_list)):
+        print "Error: Not all wig files have the same number of sites." 
+        print "       Make sure all .wig files come from the same strain."
+        sys.exit()
     
     data = numpy.zeros((K,T))
     position = numpy.zeros(T, dtype=int)
@@ -766,7 +811,14 @@ def get_data(wig_list):
             pos = int(tmp[0])
             rd = float(tmp[1])
             prev_pos = pos
-            data[j,i] = rd
+            
+            try:
+                data[j,i] = rd
+            except Exception as e:
+                print "Error: %s" % e
+                print ""
+                print "Make sure that all wig files have the same number of TA sites (i.e. same strain)"
+                sys.exit()
             position[i] = pos
             i+=1
     return (data, position)
@@ -804,7 +856,7 @@ def get_data_zero_fill(wig_list):
         return (numpy.zeros((1,0)), numpy.zeros(0), [])
     
     data = numpy.zeros((K,T))
-    position = numpy.zeros(T)
+    position = numpy.array(range(T)) + 1#numpy.zeros(T)
     for j,path in enumerate(wig_list):
         reads = []
         i = 0
@@ -813,19 +865,43 @@ def get_data_zero_fill(wig_list):
             tmp = line.split()
             pos = int(tmp[0])
             rd = float(tmp[1])
-            
-            # Fill in remaining zeros
-            for fill_pos in range(i, pos - 1):
-                data[j,fill_pos] = 0
-                position[fill_pos] = i
-                i += 1
-                
             prev_pos = pos
-            data[j,i] = rd
-            position[i] = pos
+            data[j,pos-1] = rd
             i+=1
     return (data, position)
 
+
+def get_data_w_genome(wig_list, genome):
+   
+    X = read_genome(genome)
+    N = len(X)
+    positions = []
+    pos2index = {}
+    count = 0
+    for i in range(N-1):
+        if X[i:i+2].upper() == "TA":
+            pos = i+1
+            positions.append(pos)
+            pos2index[pos] = count
+            count +=1
+
+    positions = numpy.array(positions)
+    T = len(positions)
+    K = len(wig_list)
+    data = numpy.zeros((K,T))
+    for j,path in enumerate(wig_list):
+        for line in open(path):
+            if line[0] not in "0123456789": continue
+            tmp = line.split()
+            pos = int(tmp[0])
+            rd = float(tmp[1])
+            if pos in pos2index:
+                index = pos2index[pos]
+                data[j,index] = rd
+            else:
+                print "Warning: Coordinate %d did not match a TA site in the genome. Ignoring counts." %(pos)
+    return (data, positions)
+ 
 #
 
 def combine_replicates(data, method="Sum"):
@@ -890,16 +966,7 @@ def get_wig_stats(path):
     """
     (data,position) = get_data([path])
     reads = data[0]
-    density = numpy.mean(reads>0)
-    meanrd = numpy.mean(reads)
-    nzmeanrd = numpy.mean(reads[reads>0])
-    nzmedianrd = numpy.median(reads[reads>0])
-    maxrd = numpy.max(reads)
-    totalrd = numpy.sum(reads)
-
-    skew = scipy.stats.skew(reads[reads>0])
-    kurtosis = scipy.stats.kurtosis(reads[reads>0])
-    return (density, meanrd, nzmeanrd, nzmedianrd, maxrd, totalrd, skew, kurtosis)
+    return get_data_stats(reads)
 
 #
 
@@ -1454,7 +1521,7 @@ if __name__ == "__main__":
     print "#"
 
     griffin_results = griffin_analysis(G, theta)
-    for i,gene in enumerate(sorted(G)):
+    for i,gene in enumerate(G):
         pos = gene.position
         exprun, pval = griffin_results[i][-2:]
         print "%s\t%s\t%s\t%s\t%s\t%s\t%s\t%1.1f\t%1.5f" % (gene.orf, gene.name, gene.k, gene.n, gene.r, gene.s, gene.t, exprun, pval)
