@@ -21,6 +21,7 @@ try:
 except Exception as e:
     hasWx = False
     newWx = False
+    print "EXCEPTION:", str(e)
 
 import os
 import time
@@ -105,7 +106,7 @@ class MainFrame ( wx.Frame ):
 
 
 
-        self.SetSizeHintsSz( wx.DefaultSize, wx.DefaultSize )
+        #self.SetSizeHintsSz( wx.DefaultSize, wx.DefaultSize )
         
         bSizer1 = wx.BoxSizer( wx.HORIZONTAL )
         
@@ -720,7 +721,6 @@ class TnSeekFrame(MainFrame):
             for dataset in ctrlData:
                 try:
                     path = os.path.dirname(os.path.realpath(__file__))
-                    print path
                     path = os.path.join(os.path.dirname('/pacific/home/mdejesus/transit/src/transit.py'), "pytransit/data", dataset)
                     transit_tools.transit_message("Adding Ctrl File: " + path)
                     self.loadCtrlFile(path)
@@ -1039,6 +1039,7 @@ class TnSeekFrame(MainFrame):
             if dlg.ShowModal() == wx.ID_OK:
                 paths = dlg.GetPaths()
                 print "You chose the following Control file(s):"
+                print paths
                 for fullpath in paths:
                     print "\t%s" % fullpath
                     self.loadCtrlFile(fullpath)
@@ -1935,4 +1936,61 @@ along with TRANSIT.  If not, see <http://www.gnu.org/licenses/>.
             traceback.print_exc()
 
 
+class AssumeZerosDialog(wx.Dialog):
+
+    def __init__(self, *args, **kw):
+
+        self.ID_HIMAR1 = wx.NewId()
+        self.ID_TN5 = wx.NewId()
+
+        wx.Dialog.__init__(self, None, title="Dialog")
+
+        self.ID_HIMAR1 = wx.NewId()
+        self.ID_TN5 = wx.NewId()
+
+        self.SetSize((500, 300))
+        self.SetTitle("Warning:  Wig Files Do Not Include Empty Sites")
+
+        mainSizer = wx.BoxSizer(wx.VERTICAL)
+        self.SetSizer(mainSizer)
+
+        warningText = """
+
+One or more of your .wig files does not include any empty sites (i.e. sites with zero read-counts). The analysis methods in TRANSIT require knowing ALL possible insertion sites, even those without reads.
+    
+    Please indicate how you want to proceed:
+
+    As Himar1: You will need to provide the DNA sequence (.fasta format) and TRANSIT will automatically determine empty TA sites.
+
+    As Tn5: TRANSIT will assume all nucleotides are possible insertion sites. Those not included in the .wig file are assumed to be zero.
+    """
+        warningStaticBox = wx.StaticText(self, wx.ID_ANY, warningText, (-1,-1), (-1, -1), wx.ALL)
+        warningStaticBox.Wrap(480)
+        mainSizer.Add(warningStaticBox)
+
+        button_sizer = wx.BoxSizer(wx.HORIZONTAL)
+        himar1Button = wx.Button(self, self.ID_HIMAR1, label='Proceed as Himar1')
+        tn5Button = wx.Button(self, self.ID_TN5, label='Proceed as Tn5')
+        cancelButton = wx.Button(self, wx.ID_CANCEL, label='Cancel')
+
+
+        button_sizer.Add(himar1Button, flag=wx.LEFT, border=5)
+        button_sizer.Add(tn5Button, flag=wx.LEFT, border=5)
+        button_sizer.Add(cancelButton, flag=wx.LEFT, border=5)
+
+        mainSizer.Add(button_sizer,
+            flag=wx.ALIGN_CENTER|wx.TOP|wx.BOTTOM, border=10)
+
+
+        himar1Button.Bind(wx.EVT_BUTTON, self.OnClose)
+        tn5Button.Bind(wx.EVT_BUTTON, self.OnClose)
+        cancelButton.Bind(wx.EVT_BUTTON, self.OnClose)
+
+
+    def OnClose(self, event):
+
+        if self.IsModal():
+            self.EndModal(event.EventObject.Id)
+        else:
+            self.Close()
 
